//  FILE:       ExecuteDll.cpp
//              Microsoft TPC-H Kit Ver. 1.00
//              Copyright Microsoft, 1999
//              All Rights Reserved
//
//
//  PURPOSE:    Implementation of DLL Exports.
//  Contact:    Reshma Tharamal (reshmat@microsoft.com)
// 


// Note: Proxy/Stub Information
//      To build a separate proxy/stub DLL, 
//      run nmake -f ExecuteDllps.mk in the project directory.

#include "stdafx.h"
#include "resource.h"
#include <initguid.h>

#include "..\LogWriter\LogWriter.h"
#include "..\LogWriter\LogWriter_i.c"

#include "..\common\SMTime\SMTime.h"
#include "..\common\SMTime\SMTime_i.c"

#include "ExecuteDll.h"
#include "SMExecute.h"

#include "ExecuteDll_i.c"
#include "Execute.h"

CComModule _Module;

BEGIN_OBJECT_MAP(ObjectMap)
OBJECT_ENTRY(CLSID_Execute, CExecute)
END_OBJECT_MAP()

SQLHENV henv = NULL;									// ODBC environment handle

static char szCaption[] = "StepMaster";					// Message box caption

CRITICAL_SECTION hConnections;							// Critical section to serialize access to available connections
SM_Connection_Info	*p_Connections = NULL;				// Pointer to open connections
int					iConnectionCount = 0;				// Number of open connections

#ifdef _TPCH_AUDIT
	FILE *pfLogFile = NULL;								// Log file containing timestamps
	CRITICAL_SECTION hLogFileWrite;						// Critical section to serialize writes to log

	static char szFileOpenModeAppend[] = "a+";			// Log file open mode

	static char szEnvVarLogFile[] = "TPCH_LOG_FILE";	// Environment variable - initialized to 
														// log file name if timing information 
														// is to be logged
#endif

void ShowODBCErrors(SWORD fHandleType, SQLHANDLE handle);
void CloseOpenConnections();

/////////////////////////////////////////////////////////////////////////////
// DLL Entry Point

extern "C"
BOOL WINAPI DllMain(HINSTANCE hInstance, DWORD dwReason, LPVOID /*lpReserved*/)
{

    if (dwReason == DLL_PROCESS_ATTACH)
    {
        _Module.Init(ObjectMap, hInstance, &LIBID_EXECUTEDLLLib);
        DisableThreadLibraryCalls(hInstance);

#ifdef _TPCH_AUDIT
		char szMsg[MAXBUFLEN];
		LPSTR szLogFileName = getenv(szEnvVarLogFile);

		if (szLogFileName == NULL)
		{
			sprintf(szMsg, "The environment variable '%s' does not exist. "
				"Step timing information will not be written to a log.", szEnvVarLogFile);
			MessageBox(NULL, szMsg, szCaption, MB_OK);
		}
		else
		{
			if ( (pfLogFile = fopen(szLogFileName, szFileOpenModeAppend)) == NULL )
			{
				sprintf(szMsg, "The file '%s' does not exist. "
					"Step timing information will not be written to log.", szLogFileName);
				MessageBox(NULL, szMsg, szCaption, MB_OK);
			}
			else
				InitializeCriticalSection(&hLogFileWrite);
		}
#endif

		InitializeCriticalSection(&hConnections);

		p_Connections = NULL;
		iConnectionCount = 0;
		
		if (!SQL_SUCCEEDED(SQLSetEnvAttr(NULL, SQL_ATTR_CONNECTION_POOLING, (SQLPOINTER)SQL_CP_ONE_PER_HENV , 0)))
			ShowODBCErrors(SQL_HANDLE_ENV, henv);

		if (!SQL_SUCCEEDED(SQLAllocHandle(SQL_HANDLE_ENV, SQL_NULL_HANDLE, &henv)))
		{
			ShowODBCErrors(SQL_HANDLE_ENV, henv);
			return FALSE;
		}

		if (!SQL_SUCCEEDED(SQLSetEnvAttr(henv, SQL_ATTR_ODBC_VERSION, (LPVOID)SQL_OV_ODBC3, 0)))
			ShowODBCErrors(SQL_HANDLE_ENV, henv);

		SQLUINTEGER CpMatch;
		if (!SQL_SUCCEEDED(SQLGetEnvAttr(henv, SQL_ATTR_CP_MATCH, &CpMatch, 0, NULL)))
			ShowODBCErrors(SQL_HANDLE_ENV, henv);

		if (!SQL_SUCCEEDED(SQLSetEnvAttr(henv, SQL_ATTR_CP_MATCH, (SQLPOINTER)SQL_CP_STRICT_MATCH, SQL_IS_INTEGER)))
			ShowODBCErrors(SQL_HANDLE_ENV, henv);

    }
    else if (dwReason == DLL_PROCESS_DETACH)
	{

#ifdef _TPCH_AUDIT
		if (pfLogFile != NULL)
		{
			fclose(pfLogFile);
			
			DeleteCriticalSection(&hLogFileWrite);
		}
#endif

		CloseOpenConnections();

		if (henv != NULL)
			SQLFreeEnv(henv);

		DeleteCriticalSection(&hConnections);

        _Module.Term();
	}
    return TRUE;    // ok
}

void ShowODBCErrors(SWORD fHandleType, SQLHANDLE handle)
{
	UCHAR		szErrState[SQL_SQLSTATE_SIZE+1];		// SQL Error State string
	UCHAR		szErrText[SQL_MAX_MESSAGE_LENGTH+1];    // SQL Error Text string
	char		szBuffer[SQL_SQLSTATE_SIZE+SQL_MAX_MESSAGE_LENGTH+MAXBUFLEN+1] = "";   
														// formatted Error text Buffer
	SWORD		wErrMsgLen;								// Error message length
	SQLINTEGER	dwErrCode;								// Native Error code
	SQLRETURN	nErrResult;								// Return Code from SQLGetDiagRec
	SWORD		sMsgNum = 1;							// Error sequence number

	// call SQLGetDiagRec function with proper ODBC handles, repeatedly until
	// function returns SQL_NO_DATA. 
	while ((nErrResult = SQLGetDiagRec(fHandleType, handle, sMsgNum++,
		szErrState, &dwErrCode, szErrText, SQL_MAX_MESSAGE_LENGTH-1, &wErrMsgLen))
		!= SQL_NO_DATA) 
	{
		if (!SQL_SUCCEEDED(nErrResult))
			break;
		
		wsprintf(szBuffer, SM_SQLERR_FORMAT, (LPSTR)szErrState, dwErrCode, (LPSTR)szErrText);

		MessageBox(NULL, szBuffer, szCaption, MB_OK);
	}
}

void CloseOpenConnections()
{
	// Closes all open connections
	
	if (p_Connections)
	{
		for (int iConnIndex = iConnectionCount - 1; iConnIndex >= 0; iConnIndex--)
		{
			if ((p_Connections + iConnIndex)->hdbc != SQL_NULL_HDBC)
			{
#ifdef _DEBUG
				_CrtDbgReport(_CRT_WARN, NULL, 0, NULL, "Executing SQLDisconnect.\n");
#endif
				SQLDisconnect((p_Connections + iConnIndex)->hdbc);
#ifdef _DEBUG
				_CrtDbgReport(_CRT_WARN, NULL, 0, NULL, "Executing SQLFreeHandle for hdbc.\n");
#endif
				SQLFreeHandle(SQL_HANDLE_DBC, (p_Connections + iConnIndex)->hdbc );
				(p_Connections + iConnIndex)->hdbc = SQL_NULL_HDBC;
			}
			
		}
		
		free(p_Connections);
	}
	p_Connections = NULL;
	
	return;
}

/////////////////////////////////////////////////////////////////////////////
// Used to determine whether the DLL can be unloaded by OLE

STDAPI DllCanUnloadNow(void)
{
    return (_Module.GetLockCount()==0) ? S_OK : S_FALSE;
}

/////////////////////////////////////////////////////////////////////////////
// Returns a class factory to create an object of the requested type

STDAPI DllGetClassObject(REFCLSID rclsid, REFIID riid, LPVOID* ppv)
{
    return _Module.GetClassObject(rclsid, riid, ppv);
}

/////////////////////////////////////////////////////////////////////////////
// DllRegisterServer - Adds entries to the system registry

STDAPI DllRegisterServer(void)
{
    // registers object, typelib and all interfaces in typelib
    return _Module.RegisterServer(TRUE);
}

/////////////////////////////////////////////////////////////////////////////
// DllUnregisterServer - Removes entries from the system registry

STDAPI DllUnregisterServer(void)
{
    return _Module.UnregisterServer(TRUE);
}
