//  FILE:       SMExecute.h
//              Microsoft TPC-H Kit Ver. 1.00
//              Copyright Microsoft, 1999
//              All Rights Reserved
//
//
//  PURPOSE:    Declaration of the CSMLog
//  Contact:    Reshma Tharamal (reshmat@microsoft.com)
// 
// SMLog.h : Declaration of the CSMLog

#ifndef __SMLOG_H_
#define __SMLOG_H_

#include "resource.h"       // main symbols
#include "assert.h"
#include "comdef.h"
#include "LogWriterCP.h"

#define	WRITE_BUFFER_SIZE		8*1024
#define	MAX_NUM_BUFFERS			2
#define ERR_BUFFER_SIZE			512
#define ERR_SET_FILE_POINTER	0xFFFFFFFF

/////////////////////////////////////////////////////////////////////////////
// CSMLog
class ATL_NO_VTABLE CSMLog : 
	public CComObjectRootEx<CComSingleThreadModel>,
	public CComCoClass<CSMLog, &CLSID_SMLog>,
	public ISupportErrorInfo,
	public IConnectionPointContainerImpl<CSMLog>,
	public IDispatchImpl<ISMLog, &IID_ISMLog, &LIBID_LOGWRITERLib>,
	public CProxy_ISMLogEvents< CSMLog >
{
public:
	CSMLog()
	{
		m_bAppend = FALSE;
		m_bInitialized = FALSE;

        m_hTxnFile = INVALID_HANDLE_VALUE;
        hIoComplete = NULL;
        hLogFileIo = NULL;
        
		for (int i=0;i<MAX_NUM_BUFFERS;i++)
			pBuffer[i] = NULL;
        pCurrent = NULL;

        m_szFile = NULL;
        m_szHeader = NULL;
        dwError = 0;
	}

    ~CSMLog()
    {
		if (m_hTxnFile != INVALID_HANDLE_VALUE)
			CloseLogFile();
		
		for (int i=0;i<MAX_NUM_BUFFERS;i++)
		{
			if (pBuffer[i] != NULL)
				VirtualFree(pBuffer[i], 0, MEM_RELEASE);
		}

		if (m_szFile)
			SysFreeString(m_szFile);
		m_szFile = NULL;

		if (m_szHeader)
			SysFreeString(m_szHeader);
		m_szHeader = NULL;

		if (hIoComplete != INVALID_HANDLE_VALUE)
			CloseHandle(hIoComplete);
		
		if (hLogFileIo != INVALID_HANDLE_VALUE)
			CloseHandle(hLogFileIo);
		
	}

DECLARE_REGISTRY_RESOURCEID(IDR_SMLOG)

DECLARE_PROTECT_FINAL_CONSTRUCT()

BEGIN_COM_MAP(CSMLog)
	COM_INTERFACE_ENTRY(ISMLog)
	COM_INTERFACE_ENTRY(IDispatch)
	COM_INTERFACE_ENTRY(ISupportErrorInfo)
	COM_INTERFACE_ENTRY(IConnectionPointContainer)
	COM_INTERFACE_ENTRY_IMPL(IConnectionPointContainer)
END_COM_MAP()
BEGIN_CONNECTION_POINT_MAP(CSMLog)
CONNECTION_POINT_ENTRY(DIID__ISMLogEvents)
END_CONNECTION_POINT_MAP()


// ISupportsErrorInfo
	STDMETHOD(InterfaceSupportsErrorInfo)(REFIID riid);

// ISMLog
public:
	STDMETHOD(Init)();
	STDMETHOD(put_Append)(/*[in]*/ BOOL newVal);
	STDMETHOD(WriteField)(/*[in]*/ BSTR szMsg);
	STDMETHOD(WriteLine)(/*[in]*/ BSTR szMsg);
	STDMETHOD(put_FileHeader)(/*[in]*/ BSTR newVal);
	STDMETHOD(put_FileName)(/*[in]*/ BSTR newVal);

//	typedef enum err
private:

	BOOL		m_bAppend;
	BOOL		m_bInitialized;

	HANDLE		m_hTxnFile;				//handle to log file
	HANDLE		hIoComplete;			//event to signify that there are no pending IOs
	HANDLE		hLogFileIo;				//event to signal the IO thread to write the inactive buffer

	BYTE		*pBuffer[MAX_NUM_BUFFERS];
	BYTE		*pCurrent;				//ptr to current buffer
	int			iActiveBuffer;			//indicates which buffer is active: 0 or 1
	int			iIoBuffer;				//buffer for any pending IO operation

	DWORD		dwError;

	DWORD		iBufferSize;			//buffer allocated size
	DWORD		iBytesFreeInBuffer;		//total bytes available for use in buffer
	DWORD		iWriteSize;				//bytes to write to file

	BSTR		m_szFile;				//name of the file to write to
	BSTR		m_szHeader;				//header to be printed to the file (optional)

private:
	static void		LogFileIO(void *p);
	HRESULT 		Write(BYTE *ptr, DWORD iSize);
	STDMETHODIMP	WriteToFile(BSTR szMsg);
	void			CloseLogFile(void);
	STDMETHODIMP	RaiseSystemError(void);
};

#endif //__SMLOG_H_
