Attribute VB_Name = "Connections"
'  FILE:       ConnDtls.bas
'              Microsoft TPC-H Kit Ver. 2.7.0-1005
'              Copyright Microsoft, 2008
'              All Rights Reserved
'
'
'  PURPOSE:    Contains functionality to add, modify, delete
'              and edit connection strings. Also other functions
'              specific to connection strings
'  Contact:    Reshma Tharamal (reshmat@microsoft.com)
'
Option Explicit

Private mcQueryConnection As New cConnection

' Used to indicate the source module name when errors
' are raised by this module
Private Const mstrModuleName As String = ".Connections."
Private Sub ClearPreviousSelection(bChecked As Boolean)

    If bChecked Then
        frmConnections.chkNoCount.Value = Unchecked
        frmConnections.chkStatsTime.Value = Unchecked
        frmConnections.chkStatsIO.Value = Unchecked
    End If
    
End Sub

Public Function CopyConnection(ByVal NodeIdentifier As Long, _
        Optional ByVal NodeKey As String = gstrEmptyString) As Object

    ' Returns an object populated with the data for the passed in identifier
    
    On Error GoTo CopyConnectionErr

    Set CopyConnection = gcConnections.QueryConnection(NodeIdentifier)
            
    Exit Function
    
CopyConnectionErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    Set CopyConnection = Nothing
    Err.Raise vbObjectError + errCopyFailed, _
            mstrModuleName, LoadResString(errCopyFailed)
    
End Function
Public Sub CreateConnection(ByVal cNewConnection As cConnection, _
        ByVal lngWorkspaceId As Long)
    
    ' Creates a new connection record with the properties
    ' same as the those of the passed in object
    
    Dim cConnectionToCreate As cConnection
    
    On Error GoTo CreateConnectionErr
    
    Set cConnectionToCreate = cNewConnection.Clone
    cConnectionToCreate.WorkspaceId = lngWorkspaceId
    
    ' Call a procedure to save the record
    Call InsertConnection(cConnectionToCreate)

    Set cConnectionToCreate = Nothing
    
    Exit Sub
    
CreateConnectionErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    Err.Raise vbObjectError + errCreateConnectionFailed, _
            mstrModuleName & "CreateConnection", _
            LoadResString(errCreateConnectionFailed)

End Sub

Private Sub InsertConnection(ByVal cNewConnection As cConnection)
    
    Dim iAppend As Integer
    
    On Error GoTo InsertConnectionErr

    iAppend = 0
    gcConnections.Add cNewConnection
    
    ' Load connection values in the tree and list view controls
    Call AddNode(frmMain.treStepView, frmMain.lvwStepView, _
            cNewConnection.ConnectionId, cNewConnection.ConnectionName, _
            cNewConnection.WorkspaceId, gintNodeParamConnection, cNewConnection)
    
    ' Set the tag for the workspace node to indicate that
    ' it has been modified.
    Call WspModified(cNewConnection.WorkspaceId)
    
    Exit Sub
    
InsertConnectionErr:
    ' If the error raised by the add function is due to a duplication
    ' of the connection name, then try to generate a unique name
    If Err.Number - vbObjectError = errDuplicateConnectionName Then
        iAppend = iAppend + 1
        cNewConnection.ConnectionName = cNewConnection.ConnectionName & CStr(iAppend)
        ' Try to insert the record again
        Resume
    End If
    
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    Err.Raise vbObjectError + errCreateConnectionFailed, _
            mstrModuleName, LoadResString(errCreateConnectionFailed)

End Sub
Sub ConnectionOK()

    On Error GoTo ConnectionOKErr

    ' Set the mousepointer to indicate Busy
    Call ShowBusy
    
    If frmConnections.Tag = gstrUpdateMode Then
        Call ConnectionModify
    Else
        Call ConnectionNew
    End If
    
    ' Reset the mousepointer
    Call ShowFree
    
    Exit Sub
    
ConnectionOKErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    ' Error messages, have already been displayed by the
    ' called functions
    
    ' Reset the mousepointer
    Call ShowFree
    
End Sub

Public Sub NoExecuteChecked(bEnabled As Boolean)

    Call ClearPreviousSelection(Not bEnabled)

    frmConnections.chkNoCount.Enabled = bEnabled
    frmConnections.chkParseOnly.Enabled = bEnabled
    frmConnections.chkShowQP.Enabled = bEnabled
    frmConnections.chkStatsTime.Enabled = bEnabled
    frmConnections.chkStatsIO.Enabled = bEnabled
    
End Sub
Public Sub ParseOnlyChecked(bEnabled As Boolean)

    Call ClearPreviousSelection(Not bEnabled)
    
    frmConnections.chkNoCount.Enabled = bEnabled
    frmConnections.chkNoExecute.Enabled = bEnabled
    frmConnections.chkShowQP.Enabled = bEnabled
    frmConnections.chkStatsTime.Enabled = bEnabled
    frmConnections.chkStatsIO.Enabled = bEnabled
    
End Sub
Public Sub ResetConnProperties()
    
    Dim cNewConn As cConnection

    On Error GoTo ResetConnPropertiesErr
    
    ' Initialize the form with default values for the connection properties
    Set cNewConn = New cConnection
    
    frmConnections.chkNoCount = IIf(cNewConn.NoCountDisplay, Checked, Unchecked)
    frmConnections.chkNoExecute = IIf(cNewConn.NoExecute, Checked, Unchecked)
    frmConnections.chkParseOnly = IIf(cNewConn.ParseQueryOnly, Checked, Unchecked)
    frmConnections.chkQuotedIds = IIf(cNewConn.QuotedIdentifiers, Checked, Unchecked)
    frmConnections.chkAnsiNulls = IIf(cNewConn.AnsiNulls, Checked, Unchecked)
    frmConnections.chkShowQP = IIf(cNewConn.ShowQueryPlan, Checked, Unchecked)
    frmConnections.chkStatsTime = IIf(cNewConn.ShowStatsTime, Checked, Unchecked)
    frmConnections.chkStatsIO = IIf(cNewConn.ShowStatsIO, Checked, Unchecked)
    frmConnections.txtRowCount = Trim$(Str(cNewConn.RowCount))
    frmConnections.txtQueryTimeout = Trim$(Str(cNewConn.QueryTimeOut))
    
    Set cNewConn = Nothing
    Exit Sub

ResetConnPropertiesErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    ShowError errResetConnPropertiesFailed
    
End Sub

Public Sub ShowQPChecked(bEnabled As Boolean)

    Call ClearPreviousSelection(Not bEnabled)
    
    frmConnections.chkNoCount.Enabled = bEnabled
    frmConnections.chkNoExecute.Enabled = bEnabled
    frmConnections.chkParseOnly.Enabled = bEnabled
    frmConnections.chkStatsTime.Enabled = bEnabled
    frmConnections.chkStatsIO.Enabled = bEnabled
    
End Sub
Public Sub NoExecuteClicked()

    Call NoExecuteChecked(frmConnections.chkNoExecute.Value = Unchecked)
    
End Sub
Public Sub ParseOnlyClicked()

    Call ParseOnlyChecked(frmConnections.chkParseOnly.Value = Unchecked)
    
End Sub
Public Sub ShowQPClicked()

    Call ShowQPChecked(frmConnections.chkShowQP.Value = Unchecked)
    
End Sub

Sub ShowModifyConnectionForm(Optional ByVal lngIdentifier As Long = 0)

    Dim lngConnId As Long
    
    On Error GoTo ShowModifyConnectionFormErr

    If lngIdentifier = 0 Then
        lngConnId = IdentifierSelected
    Else
        lngConnId = lngIdentifier
    End If

    BugAssert lngConnId <> 0, "ConnectionModify called when an item wasn't selected!"
    Set mcQueryConnection = gcConnections.QueryConnection(lngConnId)
    
    Call CopyConnClassToForm(mcQueryConnection)
    
    frmConnections.Tag = gstrUpdateMode
    
    ' Reset the mousepointer
    ShowFree
    
    frmConnections.Show vbModal, frmMain
    
    Exit Sub
    
ShowModifyConnectionFormErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    Err.Raise vbObjectError + errShowFormFailed, _
            mstrModuleName & "ShowModifyConnectionForm", LoadResString(errShowFormFailed)
    
End Sub

Sub ShowCreateConnectionForm(Optional ByVal lngWorkspaceId As Long = 0)

    Dim lngWorkspace As Long
    Dim cNewConn As cConnection
    
    On Error GoTo ShowCreateConnectionFormErr

    If lngWorkspaceId = 0 Then
        lngWorkspace = WorkspaceSelected
    Else
        lngWorkspace = lngWorkspaceId
    End If
    
    frmConnections.Tag = gstrInsertMode
    
    ' Initialize the form with default values for the connection properties
    Set cNewConn = New cConnection
    cNewConn.WorkspaceId = lngWorkspace
    Call CopyConnClassToForm(cNewConn)
    
    ' Reset the mousepointer
    ShowFree
    
    frmConnections.Show vbModal, frmMain
    
    Set cNewConn = Nothing
    
    Exit Sub
    
ShowCreateConnectionFormErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    Err.Raise vbObjectError + errShowFormFailed, _
            mstrModuleName & "ShowCreateConnectionForm", LoadResString(errShowFormFailed)
    
End Sub
Public Sub ConnectionModify()

    Dim cNewConnection As cConnection
    
    On Error GoTo ConnectionModifyErr

    Set cNewConnection = mcQueryConnection.Clone
    
    Call CopyConnFormToClass(cNewConnection)
    
    ' Modify the parameter record in the array
    gcConnections.Modify cNewConnection
    
    ' Modify parameter values in the list and tree view controls
    Call UpdateView(frmMain.treStepView, frmMain.lvwStepView, _
        cNewConnection.ConnectionId, cNewConnection.ConnectionName, _
        cNewConnection, gintNodeParamConnection)

    ' Set the tag for the workspace node to indicate that
    ' it has been modified.
    Call WspModified(cNewConnection.WorkspaceId)
    
    Set cNewConnection = Nothing
    
    ' Now that we're done, unload the form
    Unload frmConnections
    Exit Sub
    
ConnectionModifyErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    ShowError errConnectionUpdateFailed
    
End Sub
Public Sub ConnectionDelete(Optional ByVal cConnToDelete As cConnection, _
        Optional ByVal lngIdentifier As Long = 0)

    Dim lngConnId As Long
    
    On Error GoTo ConnectionDeleteErr
    
    If cConnToDelete Is Nothing And lngIdentifier = 0 Then
        lngConnId = IdentifierSelected
    Else
        lngConnId = lngIdentifier
    End If
    
    ' Call a procedure to delete the Connection record
    Call DeleteConnectionRecord(Connection:=cConnToDelete, Identifier:=lngConnId)
    
    Exit Sub
    
ConnectionDeleteErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    gstrSource = mstrModuleName & "ConnectionDelete"
    On Error GoTo 0
    Err.Raise vbObjectError + errDeleteConnectionFailed, _
            gstrSource, _
            LoadResString(errDeleteConnectionFailed)
    
End Sub

Public Sub DeleteConnectionRecord(Optional ByVal Connection As cConnection, _
    Optional ByVal Identifier As Long = 0, _
    Optional ConnectionKey As String = gstrEmptyString)
    ' This procedure calls all the routines necessary to delete
    ' a Connection record
    
    Dim cConnToDelete As cConnection
    Dim lngConnId As Long
    
    On Error GoTo DeleteConnectionRecordErr
    
    If Not Connection Is Nothing Then
        Set cConnToDelete = Connection
        lngConnId = cConnToDelete.ConnectionId
    ElseIf Identifier > 0 Then
        lngConnId = Identifier
        Set cConnToDelete = gcConnections.QueryConnection(lngConnId)
    ElseIf ConnectionKey <> gstrEmptyString Then
        lngConnId = MakeIdentifierValid(ConnectionKey)
        Set cConnToDelete = gcConnections.QueryConnection(lngConnId)
    Else
        On Error GoTo 0
        Err.Raise vbObjectError + errMandatoryParameterMissing, _
                mstrModuleName & "DeleteConnectionRecord", _
                LoadResString(errMandatoryParameterMissing)
    End If
        
    gcConnections.Delete lngConnId

    ' Delete Connection node in the list and tree view controls
    Call DeleteViewNode(frmMain.treStepView, frmMain.lvwStepView, _
        lngConnId, gintNodeParamConnection, cConnToDelete.WorkspaceId)
    
    ' Set the tag for the workspace node to indicate that
    ' it has been modified.
    Call WspModified(cConnToDelete.WorkspaceId)
    
    Set cConnToDelete = Nothing
    Exit Sub
    
DeleteConnectionRecordErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    Err.Raise vbObjectError + errDeleteConnectionFailed, _
            mstrModuleName, _
            LoadResString(errDeleteConnectionFailed)
    
End Sub
Public Sub ConnectionNew()

    Dim cNewConnection As cConnection
    
    On Error GoTo ConnectionNewErr

    ' All checks for validity of the connection properties values will be done
    ' by the connection class
        
    Set cNewConnection = New cConnection
    
    Call CopyConnFormToClass(cNewConnection)
    
    ' Call a procedure to save the parameter record
    Call InsertConnection(cNewConnection)
    
    Set cNewConnection = Nothing
    
    ' Now that we're done, unload the parameters form
    Unload frmConnections
    
    Exit Sub
    
ConnectionNewErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    ShowError errCreateConnectionFailed

End Sub
Private Sub CopyConnClassToForm(cConn As cConnection)
    
    ' Store the workspace identifier as a hidden field on the
    ' form.
    frmConnections.lblWorkspaceId = Str(cConn.WorkspaceId)
    
    frmConnections.txtConnName = cConn.ConnectionName
    frmConnections.txtConnValue = cConn.ConnectionValue
    frmConnections.txtDescription = cConn.Description
    frmConnections.chkNoCount = IIf(cConn.NoCountDisplay, Checked, Unchecked)
    frmConnections.chkNoExecute = IIf(cConn.NoExecute, Checked, Unchecked)
    frmConnections.chkParseOnly = IIf(cConn.ParseQueryOnly, Checked, Unchecked)
    frmConnections.chkQuotedIds = IIf(cConn.QuotedIdentifiers, Checked, Unchecked)
    frmConnections.chkAnsiNulls = IIf(cConn.AnsiNulls, Checked, Unchecked)
    frmConnections.chkShowQP = IIf(cConn.ShowQueryPlan, Checked, Unchecked)
    frmConnections.chkStatsTime = IIf(cConn.ShowStatsTime, Checked, Unchecked)
    frmConnections.chkStatsIO = IIf(cConn.ShowStatsIO, Checked, Unchecked)
    frmConnections.txtRowCount = Trim$(Str(cConn.RowCount))
    frmConnections.txtQueryTimeout = Trim$(Str(cConn.QueryTimeOut))
    
    ' The following options have been disabled for now
    frmConnections.chkParseOdbcMsg.Enabled = False
    frmConnections.txtBatchSeparator.Enabled = False
    frmConnections.cboLanguage.Enabled = False
    frmConnections.chkTranslate.Enabled = False
    frmConnections.chkRegionalSettings.Enabled = False
'    frmConnections.chkParseOdbcMsg = IIf(cConn.ParseOdbcMsg, Checked, Unchecked)
'    frmConnections.txtBatchSeparator = cConn.TsqlBatchSeparator
'    frmConnections.cboLanguage.Text = cConn.ServerLanguage
'    frmConnections.chkTranslate = IIf(cConn.CharacterTranslation, Checked, Unchecked)
'    frmConnections.chkRegionalSettings = IIf(cConn.RegionalSettings, Checked, Unchecked)

End Sub
Private Sub CopyConnFormToClass(ByRef cConn As cConnection)

    cConn.ConnectionName = frmConnections.txtConnName
    cConn.ConnectionValue = frmConnections.txtConnValue
    cConn.Description = frmConnections.txtDescription
    cConn.WorkspaceId = Val(frmConnections.lblWorkspaceId)
    cConn.NoCountDisplay = IIf(frmConnections.chkNoCount = Checked, True, False)
    cConn.NoExecute = IIf(frmConnections.chkNoExecute = Checked, True, False)
    cConn.ParseQueryOnly = IIf(frmConnections.chkParseOnly = Checked, True, False)
    cConn.QuotedIdentifiers = IIf(frmConnections.chkQuotedIds = Checked, True, False)
    cConn.AnsiNulls = IIf(frmConnections.chkAnsiNulls = Checked, True, False)
    cConn.ShowQueryPlan = IIf(frmConnections.chkShowQP = Checked, True, False)
    cConn.ShowStatsTime = IIf(frmConnections.chkStatsTime = Checked, True, False)
    cConn.ShowStatsIO = IIf(frmConnections.chkStatsIO = Checked, True, False)
    
    If Not IsNumeric(frmConnections.txtRowCount) Then
        ShowError errRowCountNumeric
        Err.Raise vbObjectError + errRowCountNumeric, mstrModuleName, LoadResString(errRowCountNumeric)
    End If
    cConn.RowCount = CLng(frmConnections.txtRowCount)
    
    If Not IsNumeric(frmConnections.txtQueryTimeout) Then
        ShowError errTimeoutNumeric
        Err.Raise vbObjectError + errTimeoutNumeric, mstrModuleName, LoadResString(errTimeoutNumeric)
    End If
    cConn.QueryTimeOut = CLng(frmConnections.txtQueryTimeout)
    
    ' The following options have been disabled for now
'    cConn.ParseOdbcMsg = IIf(frmConnections.chkParseOdbcMsg = Checked, True, False)
'    cConn.TsqlBatchSeparator = frmConnections.txtBatchSeparator
'    cConn.ServerLanguage = frmConnections.cboLanguage.Text
'    cConn.CharacterTranslation = IIf(frmConnections.chkTranslate = Checked, True, False)
'    cConn.RegionalSettings = IIf(frmConnections.chkRegionalSettings = Checked, True, False)
    
End Sub
