Attribute VB_Name = "Manager"
'  FILE:       Manager.bas
'              Microsoft TPC-H Kit Ver. 2.7.0-1005
'              Copyright Microsoft, 2008
'              All Rights Reserved
'
'
'  PURPOSE:    Contains some high-level functions to add and modify
'              manager steps. Most of the actual maintenance of
'              steps is done by the Step modules.
'  Contact:    Reshma Tharamal (reshmat@microsoft.com)
'
Option Explicit

Private mcQueryStep As New cStep
Private mcQueryManager As New cManager
   
' Used to indicate the source module name when errors
' are raised by this module
Private Const mstrModuleName As String = "Manager."

Sub ShowModifyManagerStepForm(Optional ByVal lngIdentifier As Long = 0)
    ' Displays the modify manager step form to the user

    Dim lngStepId As Long
    
    On Error GoTo ShowModifyManagerStepFormErr

    Set mcQueryStep = mcQueryManager
    
    Set mcQueryStep = ProcessStepModify(lngIdentifier)
    
    Call ShowStepForm
    
    Exit Sub
    
ShowModifyManagerStepFormErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    gstrSource = mstrModuleName & "ShowModifyManagerStepForm"
    Err.Raise vbObjectError + errProcessStepModifyFailed, _
            gstrSource, _
            LoadResString(errProcessStepModifyFailed)
    
End Sub
Sub ManagerModify()

    ' Call a common procedure to carry out the step update
    Call StepModify(mcQueryStep, gintManagerStep)
    
End Sub
Public Sub ManagerNew()

    Dim cNewStep As cStep
    Dim cNewManagerStep As cManager
    
    On Error GoTo ManagerNewErr
    
    Set cNewManagerStep = New cManager

    ' Some properties of a step are not applicable to Manager steps.
    ' Those properties will be set to empty strings or zero, as
    ' applicable, by the Manager step class when an instance is created
    ' The Let functions will also set the values to empty strings or zero,
    ' as applicable, and ignore any passed in values
    Set cNewStep = cNewManagerStep
    Call PopulatePositionDtls(cCreateStep, cNewStep)
    
    ' Call a common procedure that will handle inserts for all steps
    Call StepNew(cNewStep, gintManagerStep)
    
    ' If we created the step due to an Apply then the subsequent OK should update
    ' the step
    Set mcQueryStep = cNewStep
    
    Set cNewStep = Nothing
    Set cNewManagerStep = Nothing
    Set cCreateStep = Nothing
    
    Exit Sub
    
ManagerNewErr:
    ' Log the error code raised by Visual Basic
    Call LogErrors(Errors)
    On Error GoTo 0
    Err.Raise vbObjectError + errNewStepFailed, _
            gstrSource, _
            LoadResString(errNewStepFailed)
    
End Sub

