Attribute VB_Name = "ToolsCommon"
'  FILE:       ToolsCommon.bas
'              Microsoft TPC-H Kit Ver. 2.7.0-1005
'              Copyright Microsoft, 2008
'              All Rights Reserved
'
'
'  PURPOSE:    Contains functions to remove run history and initialize
'              table creation scripts
'  Contact:    Reshma Tharamal (reshmat@microsoft.com)
'
Option Explicit

Public sCreateTables() As String

Public Const gsExtSeparator As String = "."

Public Sub DeleteRunHistory(dbFile As DAO.Database)
    ' Delete all run history records from the database, viz. the records in
    ' run_header, run_step_details and run_parameters

    Dim sDelete As String
    
    On Error GoTo DeleteRunHistoryErr
    
    sDelete = "delete from run_header "
    dbFile.Execute sDelete, dbFailOnError
    
    sDelete = "delete from run_step_details "
    dbFile.Execute sDelete, dbFailOnError
    
    sDelete = "delete from run_parameters "
    dbFile.Execute sDelete, dbFailOnError
    
    sDelete = "update att_identifiers " & _
         " set run_id = " & CStr(glMinId)
    dbFile.Execute sDelete, dbFailOnError
    
    Exit Sub

DeleteRunHistoryErr:
    LogErrors Errors
    Err.Raise vbObjectError + errDeleteDBRecordFailed, "DeleteRunHistory", _
            LoadResString(errDeleteDBRecordFailed)
    
End Sub

Public Function CreateConnectionsTableScript() As String
    ' Returns the table creation script for the workspace_connections table

    Call InitCreateSQLArray
    CreateConnectionsTableScript = sCreateTables(10)
    ReDim sCreateTables(0)
    
End Function
Public Function CreateConnectionDtlsTableScript() As String
    ' Returns the table creation script for the connection_dtls table

    Call InitCreateSQLArray
    CreateConnectionDtlsTableScript = sCreateTables(11)
    ReDim sCreateTables(0)
    
End Function

Public Sub InitCreateSQLArray()

ReDim sCreateTables(0 To 11)

sCreateTables(0) = "Create table att_identifiers (" & _
         "workspace_id               Long, " & _
         "parameter_id               Long, " & _
         "step_id                    Long, " & _
         "constraint_id              Long, " & _
         "run_id                     Long, " & _
         "connection_id              Long " & _
         ", " & FLD_ID_CONN_NAME & gstrBlank & DATA_TYPE_LONG & _
");"

sCreateTables(1) = "Create table att_steps (step_id   Long, " & _
         "version_no                 Text(255), " & _
         "step_label                 Text(255), " & _
         "step_file_name             Text(255), " & _
         "step_text                  Memo, " & _
         "start_directory            Text(255), " & _
         "workspace_id               Long, " & _
         "parent_step_id             Long, " & _
         "parent_version_no          Text(255), " & _
         "step_level                 Long, " & _
         "sequence_no                Integer, " & _
         "enabled_flag               Bit, " & _
         "degree_parallelism         Text(255), " & _
         "execution_mechanism        Text(50), " & _
         "failure_details            Text(255), " & _
         "continuation_criteria      Text(50), " & _
         "global_flag                Long, " & _
         "archived_flag              Bit, " & _
         "output_file_name           Text(255), " & _
         "error_file_name            Text(255), " & _
         "iterator_name              Text(255), " & _
         "CONSTRAINT pk_steps PRIMARY KEY (step_id, version_no) " & _
");"

'         "log_file_name              Text(255), " & _

sCreateTables(2) = "Create table att_workspaces (" & _
         "workspace_id               Long, " & _
         "workspace_name             Text(255), " & _
         "archived_flag              Bit, " & _
         "CONSTRAINT pk_workspaces PRIMARY KEY (workspace_id) " & _
");"

sCreateTables(3) = "Create table iterator_values (" & _
         "step_id                    Long, " & _
         "version_no                 Text(255), " & _
         "type                       Integer, " & _
         "iterator_value             Text(255), " & _
         "sequence_no                Integer " & _
");"

sCreateTables(4) = "Create table run_header (" & _
         "run_id                     Long, " & _
         "workspace_id               Long, " & _
         "start_time                 Currency, " & _
         "end_time                   Currency, " & _
         "CONSTRAINT pk_run_header PRIMARY KEY (run_id) " & _
");"

sCreateTables(5) = "Create table run_parameters (" & _
         "run_id                     Long, " & _
         "parameter_name             Text(255), " & _
         "parameter_value            Text(255) " & _
");"

sCreateTables(6) = "Create table run_step_details (" & _
         "run_id                     Long, " & _
         "step_id                    Long, " & _
         "version_no                 Text(255), " & _
         "instance_id                Long, " & _
         "parent_instance_id         Long, " & _
         "command                    Memo, " & _
         "iterator_value             Text(255), " & _
         "start_time                 Currency, " & _
         "end_time                   Currency, " & _
         "elapsed_time               Long " & _
");"

sCreateTables(7) = "Create table step_constraints (" & _
         "constraint_id              Long, " & _
         "step_id                    Long, " & _
         "version_no                 Text(255), " & _
         "constraint_type            Integer, " & _
         "global_step_id             Long, " & _
         "global_version_no          Text(255), " & _
         "sequence_no                Integer " & _
");"

sCreateTables(8) = "Create table workspace_parameters (" & _
         "workspace_id               Long, " & _
         "parameter_id               Long, " & _
         "parameter_name             Text(255), " & _
         "parameter_value            Text(255), " & _
         "description                Text(255), " & _
         "parameter_type             Integer, " & _
         "CONSTRAINT pk_parameters PRIMARY KEY (parameter_id) " & _
");"

sCreateTables(9) = "Create table db_details (" & _
         "db_version                 Text(50) " & _
");"

sCreateTables(10) = "Create table " & TBL_CONNECTION_STRINGS & " (" & _
         "workspace_id              Long, " & _
         "connection_id             Long, " & _
         "connection_name           Text(255), " & _
         "connection_value          Text(255), " & _
         "description               Text(255), " & _
         "no_count_display          Bit, " & _
         "no_execute                Bit, " & _
         "parse_query_only          Bit, " & _
         "ANSI_quoted_identifiers   Bit, " & _
         "ANSI_nulls                Bit, " & _
         "show_query_plan           Bit, " & _
         "show_stats_time           Bit, " & _
         "show_stats_io             Bit, " & _
         "parse_odbc_msg_prefixes   Bit, " & _
         "row_count                 long, " & _
         "tsql_batch_separator      Text(255), " & _
         "query_time_out            long, " & _
         "server_language           Text(255), " & _
         "character_translation     Bit, " & _
         "regional_settings         Bit, " & _
         "CONSTRAINT pk_connections PRIMARY KEY (connection_id) " & _
");"

' This table has been added in order to satisfy the TPC-H requirement that
' all the queries in a stream need to be executed on a single connection.
' Specify a connection for each odbc step. If the connection is of type,
' static, it should be kept open till the step execution is complete.
sCreateTables(11) = "Create table " & TBL_CONNECTION_DTLS & " (" & _
         FLD_ID_WORKSPACE & gstrBlank & DATA_TYPE_LONG & ", " & _
         FLD_ID_CONN_NAME & gstrBlank & DATA_TYPE_LONG & ", " & _
         FLD_CONN_DTL_CONNECTION_NAME & gstrBlank & DATA_TYPE_TEXT255 & ", " & _
         FLD_CONN_DTL_CONNECTION_STRING & gstrBlank & DATA_TYPE_TEXT255 & ", " & _
         FLD_CONN_DTL_CONNECTION_TYPE & gstrBlank & DATA_TYPE_INTEGER & ", " & _
         "CONSTRAINT pk_connection_name PRIMARY KEY (" & FLD_ID_CONN_NAME & ") " & _
");"

End Sub
